GitHub Actions Tool Cache
A Rust library for managing a tool cache similar to the one used in GitHub Actions.
This library allows you to find, add, download, and manage tools in a local cache directory. It supports multiple platforms and architectures.
Example
use ghactions::ToolCache;
// Create a new ToolCache instance
let tool_cache = ToolCache::new();
// Find a tool in the cache
let path = tool_cache.find("node", "latest").await
.expect("Failed to find tool in cache");
// Find a specific version of a tool in the cache
let path = tool_cache.find("node", "20.0.0").await
.expect("Failed to find tool in cache");
Re-exports
pub use arch::ToolCacheArch;pub use cache::ToolCache;pub use platform::ToolPlatform;pub use tool::Tool;
Modules
- arch
- Tool Cache CPU Architecture
- archives
- ToolCache Archives
- builder
- ToolCacheBuilder
- cache
- Tool Cache
- platform
- Tool Cache Platform
- tool
- Tool from ToolCache
Enums
- Tool
Cache Error - Tool cache errors